Configuration management commands.
Manages SaveContext settings including remote host configuration
stored at ~/.savecontext/config.json.
Structs
- Remote
Config - Remote host configuration for SSH proxy and sync.
- Save
Context Config - Top-level SaveContext configuration.
Functions
- build_
scp_ base_ args - Build base SCP connection args from remote config.
- build_
ssh_ base_ args - Build base SSH connection args from remote config.
- config_
path - Path to the global config file.
- execute
- Execute config commands.
- load_
config - Load the SaveContext configuration file.
- load_
remote_ config - Load the remote configuration, returning an error if not configured.
- shell_
quote - Shell-quote a string for safe interpolation into a remote shell command.