pub fn load_remote_config() -> Result<RemoteConfig>Expand description
Load the remote configuration, returning an error if not configured.
pub fn load_remote_config() -> Result<RemoteConfig>Load the remote configuration, returning an error if not configured.