shell_quote

Function shell_quote 

pub fn shell_quote(s: &str) -> String
Shell-quote a string for safe interpolation into a remote shell command.

Wraps the value in single quotes and escapes any embedded single quotes using the '\'' idiom (end quote, escaped literal quote, restart quote).