Module sync

Module sync 

Sync command implementations (JSONL export/import).

Sync operations are project-scoped, using the current working directory as the project path. JSONL files are written to <project>/.savecontext/ so they can be committed to git alongside the project code.

Functions

execute
Execute sync commands.