Plan model for SaveContext.
Plans represent PRDs, specs, or feature documentation that can be linked to epics and issues for tracking implementation.
Structs
- Plan
- A plan in SaveContext.
Enums
- Plan
Status - Plan status values.
Plan model for SaveContext.
Plans represent PRDs, specs, or feature documentation that can be linked to epics and issues for tracking implementation.