pub struct MutationContext {
pub op_name: String,
pub actor: String,
pub events: Vec<Event>,
pub dirty_sessions: HashSet<String>,
pub dirty_issues: HashSet<String>,
pub dirty_items: HashSet<String>,
pub dirty_plans: HashSet<String>,
pub dirty_time_entries: HashSet<String>,
}Expand description
Context for a mutation operation, tracking side effects.
This struct is passed to mutation closures to:
- Track which entities were modified (dirty tracking for sync)
- Record audit events for history
- Manage transaction state
Fields
op_name: StringName of the operation being performed.
actor: StringActor performing the operation (agent ID, user, etc.).
events: Vec<Event>Events to write at the end of the transaction.
dirty_sessions: HashSet<String>IDs of entities marked dirty for sync export.
dirty_issues: HashSet<String>dirty_items: HashSet<String>dirty_plans: HashSet<String>dirty_time_entries: HashSet<String>Implementations
Sourceimpl MutationContext
impl MutationContext
Sourcepub fn record_event(
&mut self,
entity_type: &str,
entity_id: &str,
event_type: EventType,
)
pub fn record_event( &mut self, entity_type: &str, entity_id: &str, event_type: EventType, )
Record an event for this operation.
Sourcepub fn record_change(
&mut self,
entity_type: &str,
entity_id: &str,
event_type: EventType,
old_value: Option<String>,
new_value: Option<String>,
)
pub fn record_change( &mut self, entity_type: &str, entity_id: &str, event_type: EventType, old_value: Option<String>, new_value: Option<String>, )
Record an event with old/new values for field tracking.
Sourcepub fn mark_session_dirty(&mut self, session_id: &str)
pub fn mark_session_dirty(&mut self, session_id: &str)
Mark a session as dirty for sync export.
Sourcepub fn mark_issue_dirty(&mut self, issue_id: &str)
pub fn mark_issue_dirty(&mut self, issue_id: &str)
Mark an issue as dirty for sync export.
Sourcepub fn mark_item_dirty(&mut self, item_id: &str)
pub fn mark_item_dirty(&mut self, item_id: &str)
Mark a context item as dirty for sync export.
Sourcepub fn mark_plan_dirty(&mut self, plan_id: &str)
pub fn mark_plan_dirty(&mut self, plan_id: &str)
Mark a plan as dirty for sync export.
Sourcepub fn mark_time_entry_dirty(&mut self, time_entry_id: &str)
pub fn mark_time_entry_dirty(&mut self, time_entry_id: &str)
Mark a time entry as dirty for sync export.