read_jsonl

Function read_jsonl 

pub fn read_jsonl(path: &Path) -> SyncResult<Vec<SyncRecord>>
Read all sync records from a JSONL file.

Each line is parsed as a SyncRecord. Invalid lines cause an error with the line number for debugging.

Errors

Returns an error if:

  • The file cannot be opened
  • Any line cannot be parsed as a valid SyncRecord