DeletionRecord

Struct DeletionRecord 

pub struct DeletionRecord {
    pub entity_type: EntityType,
    pub entity_id: String,
    pub project_path: String,
    pub deleted_at: String,
    pub deleted_by: String,
}
A deletion record for sync.

When a record is deleted locally, a deletion record is created so that imports on other machines can apply the deletion. Unlike data records, deletions are stored in a separate deletions.jsonl file.

Git-Friendly Design

Deletions accumulate in the JSONL file, providing a history of what was deleted. Git tracks when deletions were added, allowing teams to see what changed. Periodically, old deletions can be compacted (removed) once all machines have synced.

Fields

entity_type: EntityType

The type of entity that was deleted.

entity_id: String

The ID of the deleted entity.

project_path: String

The project path this deletion belongs to.

deleted_at: String

ISO8601 timestamp when the deletion occurred.

deleted_by: String

Actor who performed the deletion.