Module config

Module config 

Configuration management commands.

Manages SaveContext settings including remote host configuration stored at ~/.savecontext/config.json.

Structs

RemoteConfig
Remote host configuration for SSH proxy and sync.
SaveContextConfig
Top-level SaveContext configuration.

Functions

build_scp_base_args
Build base SCP connection args from remote config.
build_ssh_base_args
Build base SSH connection args from remote config.
config_path
Path to the global config file.
execute
Execute config commands.
load_config
Load the SaveContext configuration file.
load_remote_config
Load the remote configuration, returning an error if not configured.
shell_quote
Shell-quote a string for safe interpolation into a remote shell command.