pub fn count_lines(path: &Path) -> SyncResult<usize>Expand description
Count the number of lines in a JSONL file.
This is useful for showing statistics without loading all records into memory.
Errors
Returns an error if the file cannot be read.
pub fn count_lines(path: &Path) -> SyncResult<usize>Count the number of lines in a JSONL file.
This is useful for showing statistics without loading all records into memory.
Returns an error if the file cannot be read.