ensure_gitignore

Function ensure_gitignore 

pub fn ensure_gitignore(export_dir: &Path) -> SyncResult<()>
Ensure .gitignore exists in the export directory.

Creates a .gitignore file with whitelist pattern if it doesn’t exist. If the file already exists, it is not modified (user may have customized it).

Errors

Returns an error if the file cannot be written.